@@ -4,30 +4,27 @@ App::Parcimonie::Role::HasEncoding - role to provide an Encode::Encoding objet f
 
 =head1 SYNOPSIS
 
-    use MooseX::Declare;
-    class App::Parcimonie::Daemon with App::Parcimonie::Role::HasEncoding {
-        method foo (Str $bytes) { $self->encoding-> }
-    }
+    use Moo;
+    with 'App::Parcimonie::Role::HasEncoding';
+    sub foo { $self->encoding->decode("bla") }
 
     See App::Parcimonie::Daemon for a real-life usage example.
 
 =cut
 
 package App::Parcimonie::Role::HasEncoding;
-use Any::Moose 'Role';
 
-our $VERSION = '0.7.1'; # VERSION
-
-use namespace::autoclean;
-with 'App::Parcimonie::Role::HasCodeset';
 use Encode qw{find_encoding};
-use Any::Moose '::Util::TypeConstraints';
 
-class_type('Encode::Encoding');
-class_type('Encode::XS');
+use Moo::Role; # Moo::Role exports all methods declared after it's "use"'d
+use MooX::late;
+
+with 'App::Parcimonie::Role::HasCodeset';
+
+use namespace::clean;
 
 has 'encoding' => (
-    isa        => 'Encode::Encoding | Encode::XS',
+    isa        => 'Encode::Encoding',
     is         => 'ro',
     lazy_build => 1,
 );
@@ -37,5 +34,5 @@ sub _build_encoding {
     find_encoding($self->codeset);
 }
 
-no Any::Moose 'Role';
+no Moo::Role;
 1; # End of App::Parcimonie::Role::HasEncoding
